<?php
/**
 * Default theme options.
 *
 * @package Photomania
 */

if ( ! function_exists( 'photomania_get_default_theme_options' ) ) :

	/**
	 * Get default theme options
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function photomania_get_default_theme_options() {

		$defaults = array();

		// Header.
		$defaults['show_title']                 = true;
		$defaults['show_tagline']               = false;
		$defaults['enable_sticky_primary_menu'] = false;

		// Layout.
		$defaults['global_layout']           = 'no-sidebar';
		$defaults['archive_layout']          = 'masonry';
		$defaults['archive_image']           = 'large';
		$defaults['archive_image_alignment'] = 'center';
		$defaults['single_image']            = 'large';
		$defaults['single_image_alignment']  = 'center';

		// Home Page.
		$defaults['home_content_status'] = true;

		// Pagination.
		$defaults['pagination_type'] = 'numeric';

		// Content Meta.
		$defaults['show_meta_date']       = true;
		$defaults['show_meta_author']     = true;
		$defaults['show_meta_categories'] = true;
		$defaults['show_meta_tags']       = true;
		$defaults['show_meta_comment']    = true;

		// Footer.
		$defaults['copyright_text']        = esc_html__( 'Copyright &copy; [the-year] [the-site-link]. All rights reserved.', 'photomania-pro' );
		$defaults['powered_by_text']       = esc_html__( 'Photomania Pro by ', 'photomania-pro' ) . '<a target="_blank" rel="designer" href="https://wenthemes.com/">WEN Themes</a>';
		$defaults['reset_footer_content']  = false;
		$defaults['show_social_in_footer'] = false;
		$defaults['go_to_top']             = true;

		// Footer widgets.
		$defaults['enable_footer_widgets_background_image'] = false;
		$defaults['footer_widgets_background_image']        = '';

		// Blog.
		$defaults['excerpt_length']     = 40;
		$defaults['read_more_text']     = esc_html__( 'Read more', 'photomania-pro' );
		$defaults['exclude_categories'] = '';

		// Author Bio.
		$defaults['author_bio_in_single']           = true;
		$defaults['author_bio_show_recent_posts']   = false;
		$defaults['author_bio_recent_posts_number'] = 3;

		// Breadcrumb.
		$defaults['breadcrumb_type'] = 'simple';

		// Social share.
		$defaults['social_share_enable_archive']     = true;
		$defaults['social_share_enable_single_post'] = true;
		$defaults['social_share_enable_single_page'] = false;

		// Advanced.
		$defaults['custom_css'] = '';

		// Homepage Sections.
		$defaults['homepage_sections'] = 'portfolio,front-page-widgets,home-content-status';

		// Homepage Services.
		$defaults['services_title']  = esc_html__( 'Services', 'photomania-pro' );
		$defaults['services_number'] = 5;
		$defaults['services_column'] = 5;

		// Homepage Portfolio.
		$defaults['portfolio_title']         = esc_html__( 'Recent Works', 'photomania-pro' );
		$defaults['portfolio_category']      = array();
		$defaults['portfolio_number']        = 10;
		$defaults['portfolio_column']        = 3;
		$defaults['portfolio_enable_popup']  = true;
		$defaults['portfolio_enable_social'] = true;
		$defaults['portfolio_enable_browse'] = false;

		// Homepage Latest News.
		$defaults['latest_news_title']          = esc_html__( 'Latest News', 'photomania-pro' );
		$defaults['latest_news_category']       = 0;
		$defaults['latest_news_number']         = 4;
		$defaults['latest_news_column']         = 4;
		$defaults['latest_news_excerpt_length'] = 10;

		// Homepage Testimonials.
		$defaults['testimonials_title']            = esc_html__( 'Testimonials', 'photomania-pro' );
		$defaults['testimonials_category']         = 0;
		$defaults['testimonials_number']           = 4;
		$defaults['testimonials_background_image'] = '';

		// Homepage Team.
		$defaults['team_title']    = esc_html__( 'Our Team', 'photomania-pro' );
		$defaults['team_category'] = 0;
		$defaults['team_number']   = 4;
		$defaults['team_column']   = 4;

		// Homepage Call To Action.
		$defaults['cta_title']                 = esc_html__( 'We are creative', 'photomania-pro' );
		$defaults['cta_description']           = esc_html__( 'This is about you. Always be yourself, express yourself, have faith in yourself, do not go out and look for a successful personality and duplicate it.', 'photomania-pro' );
		$defaults['cta_primary_button_text']   = esc_html__( 'Know more', 'photomania-pro' );
		$defaults['cta_primary_button_url']    = '#';
		$defaults['cta_secondary_button_text'] = '';
		$defaults['cta_secondary_button_url']  = '';

		// Font.
		$font_keys = photomania_get_font_family_theme_settings_options();
		if ( ! empty( $font_keys ) ) {
			foreach ( $font_keys as $k => $v ) {
			  $defaults[ $k ] = $v['default'];
			}
		}
		$defaults['reset_font_settings'] = false;

		// Slider Options.
		$defaults['featured_slider_status']              = 'home-page';
		$defaults['featured_slider_transition_effect']   = 'fadeout';
		$defaults['featured_slider_transition_delay']    = 3;
		$defaults['featured_slider_transition_duration'] = 1;
		$defaults['featured_slider_enable_caption']      = true;
		$defaults['featured_slider_enable_arrow']        = false;
		$defaults['featured_slider_enable_pager']        = true;
		$defaults['featured_slider_enable_autoplay']     = true;
		$defaults['featured_slider_enable_searchform']   = true;
		$defaults['featured_slider_type']                = 'demo-slider';
		$defaults['featured_slider_number']              = 3;
		$defaults['featured_slider_category']            = '';
		$defaults['featured_slider_tag']                 = '';

		// Color.
		$colors = photomania_get_default_colors();
		if ( ! empty( $colors ) ) {
		  foreach ( $colors as $key => $val ) {
		    $defaults[ $key ] = $val;
		  }
		}

		// Pass through filter.
		$defaults = apply_filters( 'photomania_filter_default_theme_options', $defaults );
		return $defaults;
	}

endif;
